@@ -1,4 +1,5 @@
 import asyncio
+import json
 
 import aiohttp
 from notecoin.huobi.connection import (RestApiSyncClient, SubscribeClient,
@@ -7,9 +8,7 @@ from notecoin.huobi.constant import (AccountBalanceMode, AccountType,
                                      HttpMethod, TransferFuturesPro,
                                      TransferMasterType,
                                      get_default_server_url)
-from notecoin.huobi.model.account import AccountBalance
-from notecoin.huobi.utils import (accounts_update_channel,
-                                  request_account_list_channel)
+from notecoin.huobi.utils import get_current_timestamp
 from notecoin.huobi.utils.input_checker import (check_currency, check_in_list,
                                                 check_should_not_none)
 
@@ -38,7 +37,7 @@ class AccountClient(object):
         channel = "/v1/account/accounts"
         return self.rest_api_sync_client.request_process(HttpMethod.GET_SIGN, channel, {})
 
-    def get_balance(self, account_id: 'int'):
+    def get_balance(self, account_id: int):
         """
         Get the account list.
         :return: The list of accounts data.
@@ -115,10 +114,7 @@ class AccountClient(object):
             pass
 
         for account_id, account_balance_json in account_balance_json_map.items():
-            account_balance = AccountBalance.json_parse(account_balance_json.get("data", {}))
-            account_obj_tmp = account_obj_map.get(account_id, None)
-            account_balance.subtype = None if account_obj_tmp is None else account_obj_tmp.subtype
-            account_balance_list.append(account_balance)
+            account_balance_list.append(account_balance_json.get("data", {}))
 
         del account_balance_json_map
         del tasks
@@ -152,7 +148,7 @@ class AccountClient(object):
         channel = "/v1/subuser/aggregate-balance"
         return self.rest_api_sync_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
-    def transfer_between_parent_and_subuser(self, sub_uid: 'int', currency: 'str', amount: 'float',
+    def transfer_between_parent_and_subuser(self, sub_uid: int, currency: str, amount: float,
                                             transfer_type: TransferMasterType):
         """
         Transfer Asset between Parent and Sub Account.
@@ -202,6 +198,15 @@ class AccountClient(object):
         else:
             mode = AccountBalanceMode.BALANCE
 
+        def accounts_update_channel(_mode=0):
+            channel = dict()
+            channel["action"] = "sub"
+            if _mode is None:
+                channel["ch"] = "accounts.update"
+            else:
+                channel["ch"] = "accounts.update#{mode}".format(mode=_mode)
+            return json.dumps(channel)
+
         def subscription(connection):
             connection.send(accounts_update_channel(mode))
 
@@ -225,12 +230,19 @@ class AccountClient(object):
 
         check_should_not_none(callback, "callback")
 
+        def request_account_list_channel(_client_req_id=None):
+            channel = dict()
+            channel["op"] = "req"
+            channel["topic"] = "accounts.list"
+            channel["cid"] = str(_client_req_id) if _client_req_id else str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             connection.send(request_account_list_channel(client_req_id))
 
         self.web_socket_req_client.execute_subscribe_v1(subscription, callback, error_handler, is_trade=True)
 
-    def transfer_between_futures_and_pro(self, currency: 'str', amount: 'float',
+    def transfer_between_futures_and_pro(self, currency: str, amount: float,
                                          transfer_type: TransferFuturesPro) -> int:
         """
         Transfer Asset between Futures and Contract.
@@ -254,27 +266,9 @@ class AccountClient(object):
 
         return self.rest_api_sync_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
-    def get_account_balance_by_subuid(self, sub_uid):
-        """
-        Get account balance of a sub-account.
-
-        :param sub_uid: the specified sub account id to get balance for.
-        :return: the balance of a sub-account specified by sub-account uid.
-        """
-        check_should_not_none(sub_uid, "sub-uid")
-        params = {
-            "sub-uid": sub_uid
-        }
-
-        def get_channel():
-            path = "/v1/account/accounts/{}"
-            return path.format(sub_uid)
-
-        return self.rest_api_sync_client.request_process(HttpMethod.GET_SIGN, get_channel(), params)
-
-    def get_account_history(self, account_id: 'int', currency: 'str' = None,
-                            transact_types: 'str' = None, start_time: 'int' = None, end_time: 'int' = None,
-                            sort: 'str' = None, size: 'int' = None):
+    def get_account_history(self, account_id: int, currency: str = None,
+                            transact_types: str = None, start_time: int = None, end_time: int = None,
+                            sort: str = None, size: int = None):
         """
         get account change record
         :param account_id: account id (mandatory)
@@ -305,7 +299,7 @@ class AccountClient(object):
         channel = "/v1/account/history"
         return self.rest_api_sync_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
-    def post_sub_uid_management(self, sub_uid: 'int', action: 'str'):
+    def post_sub_uid_management(self, sub_uid: int, action: str):
         """
         use to freeze or unfreeze the sub uid
 
@@ -322,9 +316,9 @@ class AccountClient(object):
         channel = "/v2/sub-user/management"
         return self.rest_api_sync_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
-    def get_account_ledger(self, account_id: 'int', currency: 'str' = None, transact_types: 'str' = None,
-                           start_time: 'int' = None, end_time: 'int' = None, sort: 'str' = None, limit: 'int' = None,
-                           from_id: 'int' = None) -> list:
+    def get_account_ledger(self, account_id: int, currency: str = None, transact_types: str = None,
+                           start_time: int = None, end_time: int = None, sort: str = None, limit: int = None,
+                           from_id: int = None) -> list:
         """
         get account ledger
         :param from_id:  from_id:
@@ -357,8 +351,8 @@ class AccountClient(object):
         channel = "/v2/account/ledger"
         return self.rest_api_sync_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
-    def post_account_transfer(self, from_user: 'int', from_account_type: 'str', from_account: 'int', to_user: 'int',
-                              to_account_type: 'str', to_account: 'int', currency: 'str', amount: 'str'):
+    def post_account_transfer(self, from_user: int, from_account_type: str, from_account: int, to_user: int,
+                              to_account_type: str, to_account: int, currency: str, amount: str):
         check_should_not_none(from_user, "from-user")
         check_should_not_none(from_account_type, "from-account-type")
         check_should_not_none(from_account, "from_account")
@@ -383,7 +377,7 @@ class AccountClient(object):
         channel = "/v1/account/transfer"
         return self.rest_api_sync_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
-    def get_account_asset_valuation(self, account_type, valuation_currency: 'str' = None, sub_uid: 'str' = None):
+    def get_account_asset_valuation(self, account_type, valuation_currency: str = None, sub_uid: str = None):
         check_should_not_none(account_type, "account-type")
 
         params = {
@@ -395,7 +389,7 @@ class AccountClient(object):
 
         return self.rest_api_sync_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
-    def get_account_point(self, sub_uid: 'str' = None):
+    def get_account_point(self, sub_uid: str = None):
         params = {
             "subUid": sub_uid
         }
@@ -403,7 +397,7 @@ class AccountClient(object):
 
         return self.rest_api_sync_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
-    def post_point_transfer(self, from_uid: 'str', to_uid: 'str', group_id: 'str', amount: 'str'):
+    def post_point_transfer(self, from_uid: str, to_uid: str, group_id: str, amount: str):
         channel = "/v2/point/transfer"
         params = {
             "fromUid": from_uid,
