@@ -174,7 +174,7 @@ class HistoryDownload:
         all_res = []
         interval = end_date - start_date + timedelta(days=1)
         if interval.days > 10:
-            for index in tqdm(range(interval.days)):
+            for index in tqdm(range(interval.days), desc=f'{symbol}'):
                 current = start_date + timedelta(days=index)
                 all_res.append(self.download_symbol_period_day(path_url, symbol, period, current, *args, **kwargs))
         else:
@@ -191,7 +191,7 @@ class HistoryDownload:
         all_symbols = all_symbols or self.all_symbols
         all_periods = all_periods or self.all_periods
         if len(all_symbols) > 10:
-            for symbol in tqdm(all_symbols):
+            for symbol in tqdm(all_symbols, desc='download symbols'):
                 for period in all_periods:
                     all_oks, all_errs = self.download_symbol_period(symbol, period, start_date, end_date, *args,
                                                                     **kwargs)
